"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defineRule = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
const eslint_compat_utils_1 = require("eslint-compat-utils");
const UNEXPECTED_ERROR_LOCATION = { line: 1, column: 0 };
function defineRule(ruleName, rule) {
    return {
        meta: Object.assign(Object.assign({}, rule.meta), { docs: Object.assign(Object.assign({}, rule.meta.docs), { url: 'https://github.com/intlify/eslint-plugin-svelte/blob/main/docs/rules/' +
                    ruleName +
                    '.md' }) }),
        create(context) {
            const sourceCode = (0, eslint_compat_utils_1.getSourceCode)(context);
            if (!sourceCode.parserServices.isSvelte) {
                const filename = (0, eslint_compat_utils_1.getFilename)(context);
                if (isSvelteFile(filename)) {
                    context.report({
                        loc: UNEXPECTED_ERROR_LOCATION,
                        message: 'Use the latest svelte-eslint-parser. See also https://github.com/intlify/eslint-plugin-svelte/blob/main/docs/started.md#faq'
                    });
                }
                return {};
            }
            return rule.create(context);
        }
    };
}
exports.defineRule = defineRule;
function isSvelteFile(filename) {
    if (!filename.includes('.svelte')) {
        return false;
    }
    let target = filename;
    while (!(0, fs_1.existsSync)(target)) {
        const next = (0, path_1.dirname)(target);
        if (!next || next === target) {
            return false;
        }
        target = next;
    }
    return (0, path_1.extname)(target) === '.svelte';
}
